@@ -101,14 +101,27 @@ class SpellingBuilder(Builder):
             mod = importlib.import_module(module_name)
             yield getattr(mod, class_name)
 
-    def get_wordlist_filename(self):
+    def get_configured_wordlist_filenames(self):
+        "Returns the configured wordlist filenames."
         word_list = self.config.spelling_word_list_filename
         if word_list is None:
-            word_list = 'spelling_wordlist.txt'
+            word_list = ['spelling_wordlist.txt']
 
-        if not isinstance(word_list, list):
-            return os.path.join(self.srcdir, word_list)
+        if isinstance(word_list, str):
+            # Wordlist is a string. Split on comma in case it came
+            # from the command line, via -D, and has multiple values.
+            word_list = word_list.split(',')
 
+        return [
+            os.path.join(self.srcdir, p)
+            for p in word_list
+        ]
+
+    def get_wordlist_filename(self):
+        "Returns the filename of the wordlist to use when checking content."
+        filenames = self.get_configured_wordlist_filenames()
+        if len(filenames) == 1:
+            return filenames[0]
         # In case the user has multiple word lists, we combine them
         # into one large list that we pass on to the checker.
         return self._build_combined_wordlist()
@@ -121,10 +134,8 @@ class SpellingBuilder(Builder):
         combined_word_list = os.path.join(temp_dir,
                                           'spelling_wordlist.txt')
 
-        word_list = self.config.spelling_word_list_filename
-
         with open(combined_word_list, 'w', encoding='UTF-8') as outfile:
-            for word_file in word_list:
+            for word_file in self.get_configured_wordlist_filenames():
                 # Paths are relative
                 long_word_file = os.path.join(self.srcdir, word_file)
                 logger.info('Adding contents of %s to custom word list',
@@ -148,13 +159,27 @@ class SpellingBuilder(Builder):
     def get_target_uri(self, docname, typ=None):
         return ''
 
-    def format_suggestions(self, suggestions):
+    def get_suggestions_to_show(self, suggestions):
         if not self.config.spelling_show_suggestions or not suggestions:
+            return []
+        to_show = suggestions
+        try:
+            n_to_show = int(self.config.spelling_suggestion_limit)
+        except ValueError:
+            n_to_show = 0
+        if n_to_show > 0:
+            to_show = suggestions[:n_to_show]
+        return to_show
+
+    def format_suggestions(self, suggestions):
+        to_show = self.get_suggestions_to_show(suggestions)
+        if not to_show:
             return ''
-        return '[' + ', '.join('"%s"' % s for s in suggestions) + ']'
+        return '[' + ', '.join('"%s"' % s for s in to_show) + ']'
 
     TEXT_NODES = {
         'block_quote',
+        'caption',
         'paragraph',
         'list_item',
         'term',
@@ -185,14 +210,15 @@ class SpellingBuilder(Builder):
         doc_filters = []
         good_words = self.env.spelling_document_words.get(docname)
         if good_words:
-            logger.info('Extending local dictionary for %s', docname)
+            logger.debug('Extending local dictionary for %s', docname)
             doc_filters.append(filters.IgnoreWordsFilterFactory(good_words))
         self.checker.push_filters(doc_filters)
 
         for node in doctree.traverse(docutils.nodes.Text):
             if (node.tagname == '#text' and
                     node.parent and
-                    node.parent.tagname in self.TEXT_NODES):
+                    node.parent.tagname in self.TEXT_NODES and
+                    not hasattr(node, "spellingIgnore")):
 
                 # Get the location of the text being checked so we can
                 # report it in the output file. Nodes from text that
